@@ -36,6 +36,8 @@ _thrift_values_to_types = T.TDatumType._VALUES_TO_NAMES
 def _extract_row_val(desc, val):
     # type: (T.TColumnType, T.TDatum) -> Any
     typename = T.TDatumType._VALUES_TO_NAMES[desc.col_type.type]
+    if val.is_null:
+        return None
     val = getattr(val.val, _typeattr[typename] + '_val')
     base = datetime.datetime(1970, 1, 1)
     if typename == 'TIMESTAMP':
@@ -50,14 +52,22 @@ def _extract_row_val(desc, val):
 def _extract_col_vals(desc, val):
     # type: (T.TColumnType, T.TColumn) -> Any
     typename = T.TDatumType._VALUES_TO_NAMES[desc.col_type.type]
+    nulls = val.nulls
+
     vals = getattr(val.data, _typeattr[typename] + '_col')
+    vals = [None if null else v
+            for null, v in zip(nulls, vals)]
+
     base = datetime.datetime(1970, 1, 1)
     if typename == 'TIMESTAMP':
-        vals = [base + datetime.timedelta(seconds=v) for v in vals]
+        vals = [None if v is None else base + datetime.timedelta(seconds=v)
+                for v in vals]
     elif typename == 'DATE':
-        vals = [(base + datetime.timedelta(seconds=v)).date() for v in vals]
+        vals = [None if v is None else (base +
+                                        datetime.timedelta(seconds=v)).date()
+                for v in vals]
     elif typename == 'TIME':
-        vals = [seconds_to_time(v) for v in vals]
+        vals = [None if v is None else seconds_to_time(v) for v in vals]
 
     return vals
 
